export interface Clients {
    count: number;
    selected: number;
    offset: number;
    online: boolean;
    list: Client[];
}
export interface Client {
    alias: string | null;
    cid: number;
    'client-version': string;
    comment: string | null;
    online: boolean;
    'online-time': number;
    user_ref: string | null;
}
export interface ClientExtended extends Client {
    'last-sessions': Session[];
}
export interface Session {
    active: boolean;
    comment: string | null;
    dst_user_ref: number | null;
    duration: number;
    'end-time': number;
    from: {
        alias: string | null;
        cid: number;
    };
    sid: number;
    src_user_ref: number | null;
    'start-time': number;
    to: {
        alias: string | null;
        cid: number;
    };
}
export interface Sessions {
    cid: number;
    offset: number;
    selected: number;
    list: Session[];
    limit: number;
    direction: string;
    count: number;
    'duration.max': number;
    'duration.min': number;
}
export interface SystemInformation {
    'api-ver': string;
    name: string;
    standalone: boolean;
    clients: {
        online: number;
        offline: number;
    };
    sessions: {
        active: number;
        total: number;
    };
    license: {
        'api-password': string;
        expires: number;
        'has-expired': boolean;
        'license-id': string;
        'license-key': string;
        'max-clients': number;
        'max-session-time': number;
        'max-sessions': number;
        name: string;
        namespaces: string[];
        'power-user': false;
    };
}
export declare const AnyDeskAPI: ({ license, apiPassword }: {
    license: string;
    apiPassword: string;
}) => {
    authenticate: () => Promise<{
        'license-id': string;
        result: string;
    }>;
    authenticationString: (httpMethod: string, resource: string, content?: string) => string;
    clients: ({ offset, limit, online }: {
        offset: number;
        limit: number;
        online: boolean;
    }) => Promise<Clients>;
    client: (client: number) => Promise<ClientExtended>;
    closeSession: (session: number) => Promise<boolean>;
    sessions: (client?: number) => Promise<Sessions>;
    session: (session: number) => Promise<Session>;
    setAlias: (client: number, alias: string | null, company?: string) => Promise<boolean>;
    setSessionComment: (session: number, comment: string) => Promise<boolean>;
    systemInformation: () => Promise<SystemInformation>;
};
