"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AnyDeskAPI = void 0;
const auth_1 = require("./auth");
const utils_1 = require("./utils");
exports.AnyDeskAPI = ({ license, apiPassword }) => {
    const authenticate = () => __awaiter(void 0, void 0, void 0, function* () {
        const auth = auth_1.authString({ license, apiPassword, httpMethod: 'GET', resource: '/auth', content: '' });
        const response = yield utils_1.makeGetRequest('/auth', auth);
        return response;
    });
    const authenticationString = (httpMethod, resource, content = '') => {
        return auth_1.authString({ license, apiPassword, resource, httpMethod, content });
    };
    const clients = ({ offset, limit, online }) => __awaiter(void 0, void 0, void 0, function* () {
        const resource = `/clients?offset=${offset}&limit=${limit}${online ? '&online' : ''}`;
        const auth = auth_1.authString({ license, apiPassword, httpMethod: 'GET', resource, content: '' });
        return utils_1.makeGetRequest(resource, auth);
    });
    const client = (client) => __awaiter(void 0, void 0, void 0, function* () {
        const resource = `/clients/${client}`;
        const auth = auth_1.authString({ license, apiPassword, httpMethod: 'GET', resource, content: '' });
        return utils_1.makeGetRequest(resource, auth);
    });
    const closeSession = (session) => __awaiter(void 0, void 0, void 0, function* () {
        const resource = `/sessions/${session}/action`;
        const content = JSON.stringify({ action: 'close' });
        const auth = auth_1.authString({ license, apiPassword, httpMethod: 'POST', resource, content });
        return utils_1.makePostRequest(resource, content, auth);
    });
    const sessions = (client) => __awaiter(void 0, void 0, void 0, function* () {
        const resource = `/sessions${client ? `?cid=${client}` : ''}`;
        const auth = auth_1.authString({ license, apiPassword, httpMethod: 'GET', resource, content: '' });
        return utils_1.makeGetRequest(resource, auth);
    });
    const session = (session) => __awaiter(void 0, void 0, void 0, function* () {
        const resource = `/sessions/${session}`;
        const auth = auth_1.authString({ license, apiPassword, httpMethod: 'GET', resource, content: '' });
        return utils_1.makeGetRequest(resource, auth);
    });
    const setAlias = (client, alias, company = 'ad') => __awaiter(void 0, void 0, void 0, function* () {
        const resource = `/clients/${client}`;
        const content = JSON.stringify({ alias: alias ? `${alias}@${company}` : null });
        const auth = auth_1.authString({ license, apiPassword, httpMethod: 'PATCH', resource, content });
        return utils_1.makePatchRequest(resource, content, auth);
    });
    const setSessionComment = (session, comment) => __awaiter(void 0, void 0, void 0, function* () {
        const resource = `/sessions/${session}`;
        const content = JSON.stringify({ comment });
        const auth = auth_1.authString({ license, apiPassword, httpMethod: 'PATCH', resource, content });
        return utils_1.makePatchRequest(resource, content, auth);
    });
    const systemInformation = () => __awaiter(void 0, void 0, void 0, function* () {
        const auth = auth_1.authString({ license, apiPassword, httpMethod: 'GET', resource: '/sysinfo', content: '' });
        return utils_1.makeGetRequest('/sysinfo', auth);
    });
    return {
        authenticate,
        authenticationString,
        clients,
        client,
        closeSession,
        sessions,
        session,
        setAlias,
        setSessionComment,
        systemInformation
    };
};
//# sourceMappingURL=anydesk-api.js.map